/** swirl.cpp
*
*   Demonstrate OpenGL functions
*
**/
#define WIN32_LEAN_AND_MEAN
#include <stdlib.h>
#include <math.h>
#include <windows.h>
#include "GLapplic.h"

void ngon( double radius, double rotAngle, int n)
{
	const double pi = 4.0*atan(1.0);
	if(n<3) return ; //bad number of sides
	rotAngle *= pi/180; // covnert initial angle to radians.
	double angleInc = (2 * pi) / n;  //angle increment
	double xs, ys, angle;
	glBegin(GL_LINE_STRIP);
	xs = radius * cos(rotAngle);
	ys = radius * sin(rotAngle);
	for (int k=0; k<n; k++) {
		angle = rotAngle+k*angleInc;
		glVertex2f((float)(radius*cos(angle)),(float)(radius*sin(angle)));
	}
	glVertex2f((float)xs,(float)ys);
	glEnd();
}

void hex_swirl()
{
	int j;
	double radius, offset;
	radius = 1.0;
	offset = 0.0;
	for (j=0; j<24; j++) {
		ngon(radius,offset,6);
		radius -= 0.04;
		offset += 4.0;
	}
}

class MyApp: public CAppWindow
{
public:
	MyApp();
	void OnSize(int cx, int cy);
	void DrawScene();
};

MyApp::MyApp(): CAppWindow("hex swirl")
{
	Width  = 320 ;
	Height = 320 ;
}

void MyApp::OnSize(int cx, int cy)
{
	GLsizei glnWidth, glnHeight;

	glnWidth = (GLsizei) cx;
	glnHeight = (GLsizei) cy;
	glMatrixMode(GL_PROJECTION); 
	glLoadIdentity();
	gluOrtho2D(-1.1, 1.1, -1.1, 1.1);
	glViewport(0,0,glnWidth,glnHeight);	
}

void MyApp::DrawScene()
{
	glClearColor(1.0,1.0,1.0,0.0);       // set white background color
	glClear(GL_COLOR_BUFFER_BIT);     // clear the screen 
	glColor3f(0.0f, 0.0f, 0.0f);          // set the drawing color
	hex_swirl();
	glFlush();		                 // send all output to display 
}

int Main()
{
	return MyApp().Run();
}
